# coding: utf-8

from __future__ import print_function

import os
import pytest  # NOQA

from ruamel.std.pathlib import PosixPath, Path, PathLibConversionHelper

pl = PathLibConversionHelper()


def test_expand_no_user_file():
    p = PosixPath('~/def')
    assert str(p.expanduser()) == os.path.expanduser('~/def')


def test_expand_no_user_home():
    p = PosixPath('~')
    assert str(p.expanduser()) == os.path.expanduser('~')


def test_expand_user_file():
    p = PosixPath('~root/abc')
    assert str(p.expanduser()) == os.path.expanduser('~root/abc')


def test_expand_user_file_no_tilde():
    p = PosixPath('/var/tmp')
    assert str(p.expanduser()) == '/var/tmp'


def test_remove(tmpdir):
    import uuid
    x = uuid.uuid4()
    p = PosixPath(str(tmpdir) + str(x))
    with p.open('w') as fp:
        fp.write(u'bla')
    p.remove()
    assert not p.exists()


def test_getmtime():
    p = '/etc/passwd'
    assert pl.path.getmtime(p) == pl.path.getmtime(Path(p))


def test_basename():
    p = '/etc/resolv.conf'
    assert pl.path.basename(p) == pl.path.basename(Path(p))


def test_isdir():
    p = '/etc'
    assert pl.path.isdir(p)
    assert pl.path.isdir(Path(p))


def test_splitext():
    p = '/etc/resolv.conf'
    assert pl.path.splitext(p) == ('/etc/resolv', '.conf')
    assert pl.path.splitext(Path(p)) == (Path('/etc/resolv'), '.conf')


def test_hash(tmpdir):
    p = PosixPath(str(tmpdir)) / "hashtest.txt"
    p.write_bytes(b'')
    # empty string taken from https://en.wikipedia.org/wiki/SHA-2
    assert p.hash().hexdigest() == 'd14a028c2a3a2bc9476102bb288234c415a2b01f828ea62ac5b3e42f'
    assert p.hash('sha512').hexdigest() == 'cf83e1357eefb8bdf1542850d66d8007d620e4050b5715'\
        'dc83f4a921d36ce9ce47d0d13c5d85f2b0ff8318d2877eec2f63b931bd47417a81a538327af927da3e'
